@@ -12,10 +12,10 @@ class MockSerializer(Serializer):
     """Serializer that simply passes initial data to output."""
 
     def to_internal_value(self, data: Any) -> Dict[str, Any]:
-        return self.initial_data
+        return self.initial_data  # type: ignore
 
     def to_representation(self, instance: Any) -> Dict[str, Any]:
-        return self.initial_data
+        return self.initial_data  # type: ignore
 
     def create(self, validated_data: Any) -> Any:
         """Creted to satisfy linters."""
